@@ -1,9 +1,16 @@
 from dataclasses import dataclass
+from typing import Optional
 import hyperstate as hs
 
 
+@dataclass(eq=True)
+class DeepInner:
+    x: int
+
+
 @dataclass(eq=True)
 class PPO:
+    inner: Optional[DeepInner] = None
     cliprange: float = 0.2
     gamma: float = 0.99
     lambd: float = 0.95
@@ -28,12 +35,13 @@ def test_override() -> None:
             "lr=0.1",
             "steps=100",
             "ppo.cliprange=0.1",
+            "ppo.inner.x=10",
         ],
     )
 
     assert config == Config(
         lr=0.1,
         steps=100,
-        ppo=PPO(cliprange=0.1),
+        ppo=PPO(cliprange=0.1, inner=DeepInner(x=10)),
         task_id="CherryPick",
     )
